@@ -128,10 +128,12 @@ class IronicException(Exception):
 
     def __str__(self):
         """Encode to utf-8 then wsme api can consume it as well."""
-        if not six.PY3:
-            return six.text_type(self.args[0]).encode('utf-8')
-
-        return self.args[0]
+        value = self.__unicode__()
+        if six.PY3:
+            # On Python 3 unicode is the same as str
+            return value
+        else:
+            return value.encode('utf-8')
 
     def __unicode__(self):
         """Return a unicode representation of the exception message."""
@@ -791,3 +793,43 @@ class AgentConnectionFailed(IronicException):
 class NodeProtected(HTTPForbidden):
     _msg_fmt = _("Node %(node)s is protected and cannot be undeployed, "
                  "rebuilt or deleted")
+
+
+class AllocationNotFound(NotFound):
+    _msg_fmt = _("Allocation %(allocation)s could not be found.")
+
+
+class AllocationDuplicateName(Conflict):
+    _msg_fmt = _("An allocation with name %(name)s already exists.")
+
+
+class AllocationAlreadyExists(Conflict):
+    _msg_fmt = _("An allocation with UUID %(uuid)s already exists.")
+
+
+class AllocationFailed(IronicException):
+    _msg_fmt = _("Failed to process allocation %(uuid)s: %(error)s.")
+
+
+class DeployTemplateDuplicateName(Conflict):
+    _msg_fmt = _("A deploy template with name %(name)s already exists.")
+
+
+class DeployTemplateAlreadyExists(Conflict):
+    _msg_fmt = _("A deploy template with UUID %(uuid)s already exists.")
+
+
+class DeployTemplateNotFound(NotFound):
+    _msg_fmt = _("Deploy template %(template)s could not be found.")
+
+
+class InvalidDeployTemplate(Invalid):
+    _msg_fmt = _("Deploy template invalid: %(err)s.")
+
+
+class IBMCError(DriverOperationError):
+    _msg_fmt = _("IBMC exception occurred on node %(node)s. Error: %(error)s")
+
+
+class IBMCConnectionError(IBMCError):
+    _msg_fmt = _("IBMC connection failed for node %(node)s: %(error)s")
