@@ -857,15 +857,9 @@ class TestPXEUtils(db_base.DbTestCase):
         self.config(dhcp_provider='neutron', group='dhcp')
         if ip_version == 6:
             # Boot URL variable set from prior test of isc parameters.
-            expected_info = [{'opt_name': 'tag:!ipxe,59',
+            expected_info = [{'opt_name': 'tag:!ipxe6,59',
                               'opt_value': 'tftp://[ff80::1]/fake-bootfile',
                               'ip_version': ip_version},
-                             {'opt_name': 'tag:!ipxe6,59',
-                              'opt_value': 'tftp://[ff80::1]/fake-bootfile',
-                              'ip_version': ip_version},
-                             {'opt_name': 'tag:ipxe,59',
-                              'opt_value': expected_boot_script_url,
-                              'ip_version': ip_version},
                              {'opt_name': 'tag:ipxe6,59',
                               'opt_value': expected_boot_script_url,
                               'ip_version': ip_version}]
@@ -874,9 +868,6 @@ class TestPXEUtils(db_base.DbTestCase):
             expected_info = [{'opt_name': 'tag:!ipxe,67',
                               'opt_value': boot_file,
                               'ip_version': ip_version},
-                             {'opt_name': 'tag:!ipxe6,67',
-                              'opt_value': boot_file,
-                              'ip_version': ip_version},
                              {'opt_name': '66',
                               'opt_value': '192.0.2.1',
                               'ip_version': ip_version},
@@ -886,9 +877,6 @@ class TestPXEUtils(db_base.DbTestCase):
                              {'opt_name': 'tag:ipxe,67',
                               'opt_value': expected_boot_script_url,
                               'ip_version': ip_version},
-                             {'opt_name': 'tag:ipxe6,67',
-                              'opt_value': expected_boot_script_url,
-                              'ip_version': ip_version},
                              {'opt_name': 'server-ip-address',
                               'opt_value': '192.0.2.1',
                               'ip_version': ip_version}]
